Welcome to the Buildbot

# Welcome to the Buildbot!

- the Waterfall Display will give you a time-oriented summary of recent buildbot activity.
- the Grid Display will give you a developer-oriented summary of recent buildbot activity.
- the Transposed Grid Display presents the same information as the grid, but lists the revisions down the side.
- The Latest Build for each builder is here.
- Recent Builds are summarized here, one per line.
- Buildslave information
- ChangeSource information.
- About this Buildbot